null_dist: Generate randomization dist of the rank score stat

View source: R/RI_Quantile_20220919.R

null_distR Documentation

Generate randomization dist of the rank score stat

Description

Generate the null distribution of the given test statistic for an experiment with m treated out of n units.

Usage

null_dist(n, m, method.list = NULL, score = NULL, nperm = 10^5, Z.perm = NULL)

Arguments

score

The list of possible scores of the units (under a null, invariant under treatment assignment). If null will generate from the passed method.list and given n, m.

Z.perm

Matrix of possible treatment assignments. NULL will generate complete rand with nperm combinations.


li-xinran/RIQITE documentation built on July 1, 2023, 6:58 p.m.