View source: R/RI_Quantile_20220919.R
| null_dist | R Documentation |
Generate the null distribution of the given test statistic for an experiment with m treated out of n units.
null_dist(n, m, method.list = NULL, score = NULL, nperm = 10^5, Z.perm = NULL)
score |
The list of possible scores of the units (under a null, invariant under treatment assignment). If null will generate from the passed method.list and given n, m. |
Z.perm |
Matrix of possible treatment assignments. NULL will generate complete rand with nperm combinations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.