View source: R/RI_bound_20220919.R
| pval_bound | R Documentation |
Obtain the p-value for testing the bounded null hypothesis H0: tau <= c or H0: tau >= c
pval_bound(
Z,
Y,
c = 0,
method.list = list(name = "DIM"),
alternative = "greater",
Z.perm = NULL,
nperm = 10^5,
impute = "control"
)
Z |
An |
Y |
An |
c |
A scalar or vector specifying the bounded null hypothesis. |
method.list |
A list specifies the choice of the rank sum test statistic. For example, list(name = "DIM") means the difference-in-means statistic, list(name="Wilcoxon") means the Wilcoxon rank sum statistic, and list(name = "Stephenson", s = 10) means the Stephenson rank sum statistic with parameter s=10. |
alternative |
A character takes value "greater" and "less" indicating the direction of the alternative hypothesis. |
Z.perm |
A |
nperm |
A positive integer representing the number of permutations for approximating the randomization distribution of the test statistic |
impute |
A character specifies the form of the test statistic. "control" means we use the imputed control potential outcomes in the test statistic, and "both" means we use the imputed observed outcome in the test statistic. |
The p-value for testing the specified null hypothesis of interest.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.